Files
TheRock/rocm-systems/projects/hip-tests/catch/unit/occupancy/hipOccupancyMaxPotentialBlockSize.cc
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

86 lines
2.9 KiB
C++

/*
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
*
* SPDX-License-Identifier: MIT
*/
/*
Testcase Scenarios :
Unit_hipOccupancyMaxPotentialBlockSize_Positive_RangeValidation - Test correct execution of
hipOccupancyMaxPotentialBlockSize for diffrent parameter values
Unit_hipOccupancyMaxPotentialBlockSize_Positive_TemplateInvocation - Test correct execution of
hipOccupancyMaxPotentialBlockSize template for diffrent parameter values
Unit_hipOccupancyMaxPotentialBlockSize_Negative_Parameters - Test unsuccessful execution of
hipOccupancyMaxPotentialBlockSize api when parameters are invalid
*/
#include "occupancy_common.hh"
static __global__ void f1(float* a) { *a = 1.0; }
template <typename T> static __global__ void f2(T* a) { *a = 1; }
HIP_TEST_CASE(Unit_hipOccupancyMaxPotentialBlockSize_Negative_Parameters) {
// Common negative tests
MaxPotentialBlockSizeNegative([](int* gridSize, int* blockSize) {
return hipOccupancyMaxPotentialBlockSize(gridSize, blockSize, f1, 0, 0);
});
#if HT_AMD
#if 0 // EXSWHTEC-219
SECTION("Kernel function is NULL") {
int blockSize = 0;
int gridSize = 0;
// nvcc doesnt support kernelfunc(NULL) for api
HIP_CHECK_ERROR(hipOccupancyMaxPotentialBlockSize(&gridSize, &blockSize, NULL, 0, 0),
hipErrorInvalidDeviceFunction);
}
#endif
#endif
}
HIP_TEST_CASE(Unit_hipOccupancyMaxPotentialBlockSize_Positive_RangeValidation) {
hipDeviceProp_t devProp;
HIP_CHECK(hipGetDeviceProperties(&devProp, 0));
SECTION("dynSharedMemPerBlk = 0, blockSizeLimit = 0") {
MaxPotentialBlockSize(
[](int* gridSize, int* blockSize) {
return hipOccupancyMaxPotentialBlockSize(gridSize, blockSize, f1, 0, 0);
},
devProp.maxThreadsPerBlock);
}
SECTION("dynSharedMemPerBlk = sharedMemPerBlock, blockSizeLimit = maxThreadsPerBlock") {
MaxPotentialBlockSize(
[devProp](int* gridSize, int* blockSize) {
return hipOccupancyMaxPotentialBlockSize(
gridSize, blockSize, f1, devProp.sharedMemPerBlock, devProp.maxThreadsPerBlock);
},
devProp.maxThreadsPerBlock);
}
}
HIP_TEST_CASE(Unit_hipOccupancyMaxPotentialBlockSize_Positive_TemplateInvocation) {
hipDeviceProp_t devProp;
HIP_CHECK(hipGetDeviceProperties(&devProp, 0));
SECTION("dynSharedMemPerBlk = 0, blockSizeLimit = 0") {
MaxPotentialBlockSize(
[](int* gridSize, int* blockSize) {
return hipOccupancyMaxPotentialBlockSize<void (*)(int*)>(gridSize, blockSize, f2, 0, 0);
},
devProp.maxThreadsPerBlock);
}
SECTION("dynSharedMemPerBlk = sharedMemPerBlock, blockSizeLimit = maxThreadsPerBlock") {
MaxPotentialBlockSize(
[devProp](int* gridSize, int* blockSize) {
return hipOccupancyMaxPotentialBlockSize<void (*)(int*)>(
gridSize, blockSize, f2, devProp.sharedMemPerBlock, devProp.maxThreadsPerBlock);
},
devProp.maxThreadsPerBlock);
}
}